pub enum FuzzyQuery {
Vector(Vec<f64>),
And(Box<FuzzyQuery>, Box<FuzzyQuery>, TNorm),
Or(Box<FuzzyQuery>, Box<FuzzyQuery>, TConorm),
Not(Box<FuzzyQuery>),
}Expand description
Represents a fuzzy logic search query over vector space.
Variants
Vector(Vec<f64>)
A single target vector.
And(Box<FuzzyQuery>, Box<FuzzyQuery>, TNorm)
Fuzzy intersection (AND) using a t-norm.
Or(Box<FuzzyQuery>, Box<FuzzyQuery>, TConorm)
Fuzzy union (OR) using a t-conorm.
Not(Box<FuzzyQuery>)
Fuzzy negation (NOT).
Implementations
Sourceimpl FuzzyQuery
impl FuzzyQuery
Sourcepub fn extract_vectors(&self, out: &mut Vec<Vec<f64>>)
pub fn extract_vectors(&self, out: &mut Vec<Vec<f64>>)
Flatten and extract all vectors in the query graph to a list.
Sourcepub fn evaluate_indexed<F>(&self, counter: &mut usize, distance_fn: &F) -> f32
pub fn evaluate_indexed<F>(&self, counter: &mut usize, distance_fn: &F) -> f32
Evaluates the FuzzyQuery for a database item yielding a final membership score [0, 1].
distance_fn provides the distance from the database item to a specific query node via its traversal index.