pub struct BatchInsertRequest {
pub collection: String,
pub vectors: Vec<VectorData>,
pub origin_node_id: String,
pub logical_clock: u64,
pub durability: i32,
}Fields
collection: Stringvectors: Vec<VectorData>origin_node_id: Stringlogical_clock: u64durability: i32Implementations
Sourceimpl BatchInsertRequest
impl BatchInsertRequest
Sourcepub fn durability(&self) -> DurabilityLevel
pub fn durability(&self) -> DurabilityLevel
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: DurabilityLevel)
pub fn set_durability(&mut self, value: DurabilityLevel)
Sets durability to the provided enum value.