DatabaseClient

Struct DatabaseClient 

pub struct DatabaseClient<T> { /* private fields */ }

Implementations

Source

impl DatabaseClient<Channel>

pub async fn connect<D>(dst: D) -> Result<DatabaseClient<Channel>, Error>
where D: TryInto<Endpoint>, <D as TryInto<Endpoint>>::Error: Into<Box<dyn Error + Sync + Send>>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> DatabaseClient<T>

pub fn new(inner: T) -> DatabaseClient<T>

pub fn with_origin(inner: T, origin: Uri) -> DatabaseClient<T>

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> DatabaseClient<InterceptedService<T, F>>

pub fn send_compressed(self, encoding: CompressionEncoding) -> DatabaseClient<T>

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> DatabaseClient<T>

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> DatabaseClient<T>

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> DatabaseClient<T>

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn create_collection( &mut self, request: impl IntoRequest<CreateCollectionRequest>, ) -> Result<Response<StatusResponse>, Status>

Collection Management

pub async fn delete_collection( &mut self, request: impl IntoRequest<DeleteCollectionRequest>, ) -> Result<Response<StatusResponse>, Status>

pub async fn list_collections( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<ListCollectionsResponse>, Status>

pub async fn get_collection_stats( &mut self, request: impl IntoRequest<CollectionStatsRequest>, ) -> Result<Response<CollectionStatsResponse>, Status>

pub async fn insert( &mut self, request: impl IntoRequest<InsertRequest>, ) -> Result<Response<InsertResponse>, Status>

Insert vectors

pub async fn batch_insert( &mut self, request: impl IntoRequest<BatchInsertRequest>, ) -> Result<Response<InsertResponse>, Status>

pub async fn insert_text( &mut self, request: impl IntoRequest<InsertTextRequest>, ) -> Result<Response<InsertResponse>, Status>

pub async fn vectorize( &mut self, request: impl IntoRequest<VectorizeRequest>, ) -> Result<Response<VectorizeResponse>, Status>

pub async fn search_text( &mut self, request: impl IntoRequest<SearchTextRequest>, ) -> Result<Response<SearchResponse>, Status>

pub async fn delete( &mut self, request: impl IntoRequest<DeleteRequest>, ) -> Result<Response<DeleteResponse>, Status>

Delete vectors

pub async fn search( &mut self, request: impl IntoRequest<SearchRequest>, ) -> Result<Response<SearchResponse>, Status>

Search (ANN)

pub async fn search_batch( &mut self, request: impl IntoRequest<BatchSearchRequest>, ) -> Result<Response<BatchSearchResponse>, Status>

Batch Search (ANN)

pub async fn search_multi_collection( &mut self, request: impl IntoRequest<SearchMultiCollectionRequest>, ) -> Result<Response<SearchMultiCollectionResponse>, Status>

Multi-Geometry Search (v3.0)

pub async fn get_node( &mut self, request: impl IntoRequest<GetNodeRequest>, ) -> Result<Response<GraphNode>, Status>

Graph Traversal API (v2.3)

pub async fn get_neighbors( &mut self, request: impl IntoRequest<GetNeighborsRequest>, ) -> Result<Response<GetNeighborsResponse>, Status>

pub async fn get_concept_parents( &mut self, request: impl IntoRequest<GetConceptParentsRequest>, ) -> Result<Response<GetConceptParentsResponse>, Status>

pub async fn traverse( &mut self, request: impl IntoRequest<TraverseRequest>, ) -> Result<Response<TraverseResponse>, Status>

pub async fn find_semantic_clusters( &mut self, request: impl IntoRequest<FindSemanticClustersRequest>, ) -> Result<Response<FindSemanticClustersResponse>, Status>

pub async fn monitor( &mut self, request: impl IntoRequest<MonitorRequest>, ) -> Result<Response<Streaming<SystemStats>>, Status>

Stream statistics for TUI (Global or Collection tailored)

pub async fn trigger_snapshot( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<StatusResponse>, Status>

Admin Controls

pub async fn trigger_vacuum( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<StatusResponse>, Status>

pub async fn trigger_reconsolidation( &mut self, request: impl IntoRequest<ReconsolidationRequest>, ) -> Result<Response<StatusResponse>, Status>

pub async fn configure( &mut self, request: impl IntoRequest<ConfigUpdate>, ) -> Result<Response<StatusResponse>, Status>

Dynamic Configuration

pub async fn replicate( &mut self, request: impl IntoRequest<ReplicationRequest>, ) -> Result<Response<Streaming<ReplicationLog>>, Status>

Replication (Leader -> Follower)

pub async fn subscribe_to_events( &mut self, request: impl IntoRequest<EventSubscriptionRequest>, ) -> Result<Response<Streaming<EventMessage>>, Status>

CDC/Event Stream (External subscribers)

pub async fn get_digest( &mut self, request: impl IntoRequest<DigestRequest>, ) -> Result<Response<DigestResponse>, Status>

pub async fn rebuild_index( &mut self, request: impl IntoRequest<RebuildIndexRequest>, ) -> Result<Response<StatusResponse>, Status>

pub async fn sync_handshake( &mut self, request: impl IntoRequest<SyncHandshakeRequest>, ) -> Result<Response<SyncHandshakeResponse>, Status>

Delta Sync (Merkle Tree — Task 2.1) Step 1: Client sends its digest, server returns which buckets differ.

pub async fn sync_pull( &mut self, request: impl IntoRequest<SyncPullRequest>, ) -> Result<Response<Streaming<SyncVectorData>>, Status>

Step 2: Client requests vectors from specific buckets, server streams them.

pub async fn sync_push( &mut self, request: impl IntoStreamingRequest<Message = SyncVectorData>, ) -> Result<Response<SyncPushResponse>, Status>

Step 3 (optional): Client pushes its unique vectors to the server.