pub struct EventSubscriptionRequest {
pub types: Vec<i32>,
pub collection: Option<String>,
}Fields
types: Vec<i32>collection: Option<String>Implementations
Sourceimpl EventSubscriptionRequest
impl EventSubscriptionRequest
Sourcepub fn types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EventType>>
pub fn types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EventType>>
Returns an iterator which yields the valid enum values contained in types.
Sourcepub fn push_types(&mut self, value: EventType)
pub fn push_types(&mut self, value: EventType)
Appends the provided enum value to types.
Sourcepub fn collection(&self) -> &str
pub fn collection(&self) -> &str
Returns the value of collection, or the default value if collection is unset.