pub struct InsertRequest {
pub collection: String,
pub vector: Vec<f64>,
pub id: u32,
pub metadata: HashMap<String, String>,
pub origin_node_id: String,
pub logical_clock: u64,
pub durability: i32,
pub typed_metadata: HashMap<String, MetadataValue>,
}Fields
collection: Stringvector: Vec<f64>id: u32metadata: HashMap<String, String>origin_node_id: StringReplication fields
logical_clock: u64durability: i32typed_metadata: HashMap<String, MetadataValue>Implementations
Sourceimpl InsertRequest
impl InsertRequest
Sourcepub fn durability(&self) -> DurabilityLevel
pub fn durability(&self) -> DurabilityLevel
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: DurabilityLevel)
pub fn set_durability(&mut self, value: DurabilityLevel)
Sets durability to the provided enum value.