pub struct InsertTextRequest {
pub collection: String,
pub id: u32,
pub text: String,
pub metadata: HashMap<String, String>,
pub durability: i32,
}Fields
collection: Stringid: u32text: Stringmetadata: HashMap<String, String>durability: i32Implementations
Sourceimpl InsertTextRequest
impl InsertTextRequest
Sourcepub fn durability(&self) -> DurabilityLevel
pub fn durability(&self) -> DurabilityLevel
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: DurabilityLevel)
pub fn set_durability(&mut self, value: DurabilityLevel)
Sets durability to the provided enum value.